#include <igrimage.h>
#include <igrtim.h>
#include <unistd.h>
#include <stdio.h>

void ParseCommand(int argc, char *argv[], char *filename1, char *filename2);
void ITimPaletteAdd(ITim tim, const IPalette pal);

int main(int argc, char *argv[])
{
 char filename1[255], filename2[255];
 char tmpname[255];
 ITim tim;
 IImage img;

 ParseCommand(argc, argv, filename1, filename2);
 sprintf(tmpname, "%s.pcx", filename1);
 img = IImagePCXLoad(tmpname);
 if (img)
 {
  sprintf(tmpname, "%s.tim", filename2);
  tim = ITimLoad(tmpname);
  ITimPaletteAdd(tim, IImagePaletteGet(img));
  ITimSave(tim, tmpname);
  IImageDestroy(img);
  ITimDestroy(tim);
 }
 return 0;
}

void ParseCommand(int argc, char *argv[], char *filename1, char *filename2)
{
 char opt;
 int i;

 while ((opt = getopt(argc,argv,"h?")) != EOF) {
  switch (opt) {
   case 'h':
   case '?':
    printf("\
Adds a pcx palette to a tim file\n\
\n\
pcx2tim filename1[.pcx] filename2[.tim]\n\
\n\
  filename1[.pcx]  Name of pcx file\n\
  filename2[.tim]  Name of tim file\n\
");
    exit(0);
    break;
   default:
    break;
  }
 }
 if (argc - optind != 2) {
  printf("Incorrect number of parameters\n");
  exit(4);
 }
 strcpy(filename1,argv[optind]);
 if (((i=strlen(filename1))>4) && (strcmp(filename1+i-4,".pcx")==0))
  filename1[i-4]=0;
 strcpy(filename2,argv[optind+1]);
 if (((i=strlen(filename2))>4) && (strcmp(filename2+i-4,".tim")==0))
  filename2[i-4]=0;
}

void ITimPaletteAdd(ITim tim, const IPalette pal)
{
 int i;

 tim->ch++;
 tim->clut = (IUShort *)realloc(tim->clut, tim->ch * tim->cw * sizeof(IUShort));
 for (i = 0; i < tim->cw; i++)
 {
  tim->clut[(tim->ch - 1) * tim->cw + i] =
    (((IUShort)((*pal)[i][2] & 0x3E)) << 9) +
    (((IUShort)((*pal)[i][1] & 0x3E)) << 4) +
    (((IUShort)((*pal)[i][0] & 0x3E)) >> 1);
  if (tim->clut[(tim->ch - 1) * tim->cw + i] == 0)
  {
   tim->clut[(tim->ch - 1) * tim->cw + i] = 0x0000;
  }
 }
}

