#include <igrimage.h>
#include <igrtim.h>
#include <unistd.h>
#include <stdio.h>

void ParseCommand(int argc, char *argv[], char *filename, IUShort *bpp,
  IUShort *x, IUShort *y, IUShort *clutx, IUShort *cluty);

IBool transparent = IFALSE;
IColor r,g,b;

int main(int argc, char *argv[])
{
 char filename[255];
 char tmpname[255];
 IImage img;
 ITim tim;
 IUShort x, y, clutx, cluty, bpp;

 ParseCommand(argc, argv, filename, &bpp, &x, &y, &clutx, &cluty);
 sprintf(tmpname, "%s.pcx", filename);
 img = IImagePCXLoad(tmpname);
 if (img)
 {
  sprintf(tmpname, "%s.tim", filename);
  tim = IImage2Tim(img, bpp, x, y, clutx, cluty, transparent, r, g, b);
  if (tim)
  {
   ITimSave(tim, tmpname);
   ITimDestroy(tim);
  }
  IImageDestroy(img);
 }
 return 0;
}

void ParseCommand(int argc, char *argv[], char *filename, IUShort *bpp,
  IUShort *x, IUShort *y, IUShort *clutx, IUShort *cluty)
{
 char opt;
 int i;

 *bpp = ITIM_8BPP;
 while ((opt = getopt(argc,argv,"84h?")) != EOF) {
  switch (opt) {
   case 'h':
   case '?':
    printf("\
Converts a pcx file to a tim file\n\
\n\
pcx2tim [-8] [-4] filename[.pcx] x y clut_x clut_y [red green blue]\n\
\n\
  -8              Convert to 8 bits per pixel (default)\n\
  -4              Convert to 4 bits per pixel\n\
  filename[.pcx]  Name of pcx file\n\
  x               X position of TIM in video memory\n\
  y               Y position of TIM in video memory\n\
  clutx           X position of CLUT in video memory\n\
  cluty           Y position of CLUT in video memory\n\
  red             Red value of transparent color\n\
  green           Green value of transparent color\n\
  blue            Blue value of transparent color\n\
");
    exit(0);
    break;
   case '4':
    *bpp = ITIM_4BPP;
    break;
   case '8':
    *bpp = ITIM_8BPP;
    break;
   default:
    break;
  }
 }
 if ((argc - optind != 5) && (argc - optind != 8)) {
  printf("Incorrect number of parameters\n");
  exit(4);
 }
 strcpy(filename,argv[optind]);
 if (((i=strlen(filename))>4) && (strcmp(filename+i-4,".pcx")==0))
  filename[i-4]=0;
 *x = atoi(argv[optind + 1]);
 *y = atoi(argv[optind + 2]);
 *clutx = atoi(argv[optind + 3]);
 *cluty = atoi(argv[optind + 4]);
 if (argc - optind == 8)
 {
  transparent = ITRUE;
  r = atoi(argv[optind + 5]);
  g = atoi(argv[optind + 6]);
  b = atoi(argv[optind + 7]);
 }
}

